@@ -27,9 +27,14 @@
 #include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-private.h>
+#include <libgnomevfs/gnome-vfs-context.h>
+#include <libgnomevfs/gnome-vfs-cancellation.h>
+#include <libgnomevfs/gnome-vfs-cancellable-ops.h>
+#include <libgnomevfs/gnome-vfs-handle.h>
+#include <libgnomevfs/gnome-vfs-method.h>
 #include <libmedusa/medusa-search-service.h>
 #include <string.h>
+#include <unistd.h>
 
 /* Used for the search directory. */
 typedef struct {
@@ -427,6 +432,7 @@ do_open_directory (GnomeVFSMethod *method,
 		unescaped_uri_text = gnome_vfs_unescape_string (uri_text, NULL);
 		g_free (uri_text);
 		connection = medusa_search_service_connection_new (unescaped_uri_text,
+								   context,
 								   &result);
 		g_free (unescaped_uri_text);
 		if (result != GNOME_VFS_OK) {
@@ -583,7 +589,9 @@ do_read_directory (GnomeVFSMethod *method,
 			} else {
 				/* Get the file info. */
 				vfs_uri = gnome_vfs_uri_new (result_uri);
-				result = gnome_vfs_get_file_info_uri_cancellable
+				/* Ignore the return value here: we don't want to
+				   interrupt the load because of errors relating to a single file */
+				gnome_vfs_get_file_info_uri_cancellable
 					(vfs_uri, file_info, 
 					 wrapped_handle->u.real.options, 
 					 context);
@@ -597,11 +605,8 @@ do_read_directory (GnomeVFSMethod *method,
 				g_free (file_info->name);
 				file_info->name = gnome_vfs_escape_string (result_uri);
 			}
-
-			if (result == GNOME_VFS_OK) {
-				g_assert ((file_info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_FLAGS) != 0);
-				GNOME_VFS_FILE_INFO_SET_SYMLINK (file_info, TRUE);
-			}
+			GNOME_VFS_FILE_INFO_SET_SYMLINK (file_info, TRUE);
+			
 			g_free (result_uri);
 		}
 	}
@@ -644,6 +649,9 @@ do_get_file_info (GnomeVFSMethod *method,
 		get_file_info_for_virtual_directory (file_info);
 		/* Need a check here to make sure the search service
 		   is really running before returning any information */
+		if (gnome_vfs_context_check_cancellation (context)) {
+			return GNOME_VFS_ERROR_INTERRUPTED;
+		}
 		result = medusa_search_service_connection_is_available_for_uri (uri);
 		break;
 	case SEARCH_URI_TYPE_IMMEDIATE_CHILD:
@@ -1019,6 +1027,7 @@ do_create_symbolic_link (GnomeVFSMethod *method,
 }
 
 static GnomeVFSMethod method = {
+	sizeof (GnomeVFSMethod),
 	do_open,
 	do_create,
 	do_close,
