@@ -43,6 +43,7 @@
 #include <time.h>
 #include <unistd.h>
 
+
 static gboolean medusa_file_index_is_file                            (gpointer database,
                                                                       gpointer record);
 static gboolean medusa_file_index_is_text_file                       (gpointer database,
@@ -488,11 +489,16 @@ medusa_file_index_uid_can_read_file (gpointer database,
         database_record = (MedusaRDBRecord) record;
         uid_in_query = argument.number;
 
+
         /* We can skip all of this stuff if it's root */
         if (uid_in_query == 0) {
+#ifdef PERMISSIONS_CHECK_DEBUG
+                g_print ("Returning true because requestor is superuser\n");
+#endif
                 return TRUE;
         }
-        
+
+
         medusa_rdb_record_get_field_value
                 (database_record,
                  medusa_file_system_db_get_field_info (file_system_db),
@@ -500,10 +506,19 @@ medusa_file_index_uid_can_read_file (gpointer database,
                  file_system_db,
                  &permissions);
         
-        if (permissions & S_IROTH) {
+        medusa_rdb_record_get_field_value
+                (database_record,
+                 medusa_file_system_db_get_field_info (file_system_db),
+                 MEDUSA_FILE_INDEX_OWNER_FIELD_TITLE,
+                 file_system_db,
+                 &uid_in_record);
+        
+        if (uid_in_record == uid_in_query &&
+            permissions & S_IRUSR) {
 #ifdef PERMISSIONS_CHECK_DEBUG
-                printf ("Other can read the file, it is readable to everyone\n");
+                g_print ("Returning TRUE because file is owned by the user and the file is readable by the user.\n");
 #endif
+
                 return TRUE;
         }
 
@@ -514,23 +529,24 @@ medusa_file_index_uid_can_read_file (gpointer database,
                  file_system_db,
                  &gid_in_record);
 
-        if (permissions & S_IRGRP) {
-                return medusa_group_contains (gid_in_record, uid_in_query); 
-        }
-        
-        medusa_rdb_record_get_field_value
-                (database_record,
-                 medusa_file_system_db_get_field_info (file_system_db),
-                 MEDUSA_FILE_INDEX_OWNER_FIELD_TITLE,
-                 file_system_db,
-                 &uid_in_record);
-
-        if (permissions & S_IRUSR) {
-                return uid_in_record == uid_in_query;
+        if (permissions & S_IRGRP &&
+            medusa_group_contains (gid_in_record, uid_in_query)) {
+#ifdef PERMISSIONS_CHECK_DEBUG
+                g_print ("Returning TRUE because file is group readable, and user is in group that owns the file\n");
+#endif
+                return TRUE;
         }
 
-        return FALSE;
-        
+#ifdef PERMISSIONS_CHECK_DEBUG
+        if (permissions & S_IOTH) {
+                g_print ("Returning  because file is other readable\n");
+        }
+        else {
+                g_print ("Returning FALSE; file is not readable by user %d\n", uid_in_query);
+        }
+#endif
+        return permissions & S_IROTH;
+
 }
 
 gboolean
