@@ -426,6 +426,12 @@ file_index_clauses_using_index_only (void)
                                                      medusa_file_index_is_modified_after_time,
                                                     medusa_file_index_verify_file_is_modified_after_time,
                                                     MEDUSA_ARGUMENT_TYPE_NUMBER);
+        medusa_query_clauses_add_clause_with_check (clauses,
+                                                    "modified",
+                                                    "is_not",
+                                                    medusa_file_index_is_not_modified_on_date,
+                                                    medusa_file_index_verify_file_is_not_modified_on_date,
+                                                    MEDUSA_ARGUMENT_TYPE_STRING);
         medusa_query_clauses_add_clause (clauses,
                                          "owner",
                                          "has_uid",
