@@ -37,6 +37,7 @@
 #include "medusa-query-clauses.h"
 #include "medusa-rdb-record.h"
 #include "medusa-rdb-table.h"
+#include "medusa-string-list.h"
 #include "medusa-uri-list.h"
 
 
@@ -56,55 +57,49 @@ struct MedusaFileSystemDB {
 	time_t last_index_time;
 	time_t indexing_start_time;
 
-	MedusaHash *directory_names;
-	MedusaHash *file_names;
-	MedusaHash *mime_types;
-	MedusaHash *keyword_sets;
+	MedusaStringList *mime_types;
+	MedusaStringList *keyword_sets;
 
 	/* The index's vocabulary */
-	MedusaQueryClauses *clauses;
+	MedusaQueryClauses *clauses_using_index_only;
+	MedusaQueryClauses *clauses_using_index_and_uid;
 
 	/* State for the multi-pass indexing of keywords. */
 	GHashTable *keywords_by_file;
 	GHashTable *private_keyword_users_by_directory;
 };
 
-MedusaFileSystemDB *    medusa_file_system_db_new                            (const char         *root_uri,
-									      const char         *db_file_name,
-									      MedusaHash         *file_names,
-									      MedusaHash         *directory_names,
-									      const char         *mime_type_file_name,
-									      const char         *keyword_sets_file_name);
-MedusaFileSystemDB *    medusa_file_system_db_open                           (const char         *root_uri,
-									      const char         *db_file_name,
-									      MedusaHash         *file_names,
-									      MedusaHash         *directory_names,
-									      const char         *mime_type_file_name,
-									      const char         *keyword_sets_file_name);
-void                    medusa_file_system_db_index_file                     (MedusaFileSystemDB *db,
-									      int                 uri_number,
-									      GnomeVFSFileInfo   *file_info);
+MedusaFileSystemDB *    medusa_file_system_db_new                             (const char         *index_name);
+MedusaFileSystemDB *    medusa_file_system_db_open                            (const char         *index_name);
+void                    medusa_file_system_db_index_file                      (MedusaFileSystemDB *db,
+									       int                 uri_number,
+									       GnomeVFSFileInfo   *file_info);
+void                    medusa_file_system_db_move_completed_index_into_place (const char         *index_name);
+void                    medusa_file_system_db_erase_constructed_index         (const char         *index_name);
+gboolean                medusa_file_system_db_index_files_are_still_valid     (const char *index_name,
+									       time_t newest_valid_modified_time);
 
 /* Keyword indexing. */
-void                    medusa_file_system_db_add_public_keyword             (MedusaFileSystemDB *db,
-									      const char         *file_path,
-									      const char         *keyword);
-void                    medusa_file_system_db_add_private_keyword            (MedusaFileSystemDB *db,
-									      const char         *file_path,
-									      const char         *keyword,
-									      uid_t               user);
-void                    medusa_file_system_db_add_private_keywords_directory (MedusaFileSystemDB *db,
-									      const char         *directory_path,
-									      uid_t               user);
-void                    medusa_file_system_db_update_keywords                (MedusaFileSystemDB *db,
-									      MedusaURIList      *uri_list);
+void                    medusa_file_system_db_add_public_keyword              (MedusaFileSystemDB *db,
+									       const char         *file_path,
+									       const char         *keyword);
+void                    medusa_file_system_db_add_private_keyword             (MedusaFileSystemDB *db,
+									       const char         *file_path,
+									       const char         *keyword,
+									       uid_t               user);
+void                    medusa_file_system_db_add_private_keywords_directory  (MedusaFileSystemDB *db,
+									       const char         *directory_path,
+									       uid_t               user);
+void                    medusa_file_system_db_update_keywords                 (MedusaFileSystemDB *db,
+									       MedusaURIList      *uri_list);
 
 /* FIXME bugzilla.eazel.com 2712: 
    Not implemented yet */
 void                    medusa_file_system_db_update_file                    (MedusaFileSystemDB *db);
 int                     medusa_file_system_db_get_number_of_records          (MedusaFileSystemDB *db);
 MedusaRDBFieldInfo *    medusa_file_system_db_get_field_info                 (MedusaFileSystemDB *db);
-MedusaQueryClauses *    medusa_file_system_db_get_query_clauses              (MedusaFileSystemDB *db);
+MedusaQueryClauses *    medusa_file_system_db_get_query_clauses_using_index_only (MedusaFileSystemDB *db);
+MedusaQueryClauses *    medusa_file_system_db_get_query_clauses_using_index_and_uid (MedusaFileSystemDB *db);
 void                    medusa_file_system_db_free                           (MedusaFileSystemDB *db);
 void                    medusa_file_index_test                               (void);
 
