@@ -33,13 +33,24 @@
 #include "medusa-file-index.h"
 
 #include <libmedusa/medusa-index-progress.h>
+#include <medusa-idled/medusa-idled-client.h>
 
 struct MedusaMasterDB {
 	MedusaTextIndex *text_index;
 	MedusaFileSystemDB *file_system_db;
 	MedusaURIList *uri_list;
+	/* Whether we are creating the index right now
+	   or just reading.  indexing_mode = TRUE
+	   means we are creating the index */
 	gboolean indexing_mode;
+	/* Structure we use to remember and publish how
+	   much of the disk we've currently indexed */
 	MedusaIndexProgress *index_progress;
+	/* Connection to the daemon that will tell us
+	   if it's ok to currently be using CPU
+	   and memory to index */
+	gboolean use_idle_service;
+	MedusaIdledConnection *idled_connection;
 	char *root_uri;
 	MedusaLogLevel log_level;
 	int ref_count;
