@@ -549,7 +549,6 @@ replace_username_with_uid_criterion (MedusaUnparsedCriteria *criteria)
         const char *query_relation;  /* The relationship, eg, "is" */
         const char *query_object;    /* The subject, eg "root" */
 
-        g_print ("replacing user name with uid\n");
         g_return_val_if_fail (can_replace_username_with_uid (criteria), NULL);
         result = optimization_result_new ();
         
@@ -643,7 +642,6 @@ replace_group_with_gid_criterion (MedusaUnparsedCriteria *criteria)
 
         g_return_val_if_fail (can_replace_group_with_gid (criteria), NULL);
         result = optimization_result_new ();
-        g_print ("replacing group name with gid\n");        
         old_criterion = query_criterion_get_by_category (criteria,
                                                          "group is");
         query_relation = query_criterion_get_relation (old_criterion);
@@ -806,8 +804,15 @@ last_time_corresponding_to_query_object (const char *query_relation,
 static gboolean                     
 can_replace_modified_with_mtime (MedusaUnparsedCriteria *criteria)
 {
-        return query_criterion_get_by_category (criteria,
-                                                "modified") != NULL;
+        int i;
+        
+        for (i = 0; criteria[i] != NULL; i++) {
+                if (medusa_str_has_prefix (criteria[i], "modified ") &&
+                    !medusa_str_has_prefix (criteria[i], "modified is_not")) {
+                        return TRUE;
+                }
+        }
+        return FALSE;
 }
 
 static MedusaOptimizationResult *   
@@ -820,7 +825,6 @@ replace_modified_with_mtime_criteria (MedusaUnparsedCriteria *criteria)
          const char *query_relation;  /* The relationship, eg, "is" */
          const char *query_object;    /* The subject, eg "root" */
 
-        g_print ("replacing modified with mtime\n");
          g_return_val_if_fail (can_replace_modified_with_mtime (criteria), NULL);
          result = optimization_result_new ();
 
