@@ -32,8 +32,8 @@
 /* medusa-rdb-file.h: The API for the relational database file, which
    is an on disk database of information, organized into records */
 
+#include "medusa-rdb-fields.h"
 #include "medusa-tokenize.h"
-#include "medusa-rdb-query.h"
 
 typedef struct MedusaRDBFile MedusaRDBFile;
 
