@@ -226,7 +226,7 @@ is_valid_mime_type (char *mime_type)
            I am not totally sure this corresponds to
            the mime type spec.  I know it isn't complete */
         while (*mime_type != 0) {
-                if (isalpha (*mime_type) || isspace (*mime_type) || *mime_type == '-') {
+                if (isalpha ((guchar) *mime_type) || isspace ((guchar) *mime_type) || *mime_type == '-') {
                         mime_type++;
                         continue;
                 }
@@ -261,7 +261,7 @@ is_valid_mime_pattern (char *mime_pattern)
            I am not totally sure this corresponds to
            the mime pattern spec.  I know it isn't complete */
         while (*mime_pattern != 0) {
-                if (isalpha (*mime_pattern) || isspace (*mime_pattern) || *mime_pattern == '-' || *mime_pattern == '*' ||
+                if (isalpha ((guchar) *mime_pattern) || isspace ((guchar) *mime_pattern) || *mime_pattern == '-' || *mime_pattern == '*' ||
                     *mime_pattern == '/') {
                         mime_pattern++;
                         continue;
