@@ -203,8 +203,7 @@ medusa_text_index_new (const char *index_name,
 
         text_index->semantic_units = medusa_hash_new (word_file_name,
                                                       WORD_HASH_BITS);
-        text_index->last_occurrence = g_hash_table_new (g_direct_hash,
-                                                        g_direct_equal);
+        text_index->last_occurrence = g_hash_table_new (NULL, NULL);
 
 
         zero = 0;
