@@ -33,8 +33,6 @@
 #include "medusa-uri-list-encoders.h"
 #include "medusa-uri-list-private.h"
 
-
-
 void
 medusa_uri_list_filename_encode (char *result,
 				      char *file_name,
@@ -100,8 +98,8 @@ medusa_uri_list_filename_decode (char *file_name_result,
         strncpy (file_name_result, 
                  medusa_string_list_get_string (uri_list->file_names,
                                                 token),
-                 NAME_MAX - 1);
-        file_name_result[NAME_MAX - 1] = 0;
+                 FILE_NAME_MAXIMUM_LENGTH - 1);
+        file_name_result[FILE_NAME_MAXIMUM_LENGTH - 1] = 0;
 }
 
 
@@ -117,8 +115,8 @@ medusa_uri_list_directory_name_decode (char *directory_name_result,
         strncpy (directory_name_result, 
                  medusa_string_list_get_string (uri_list->directory_names,
                                                 token),
-                 NAME_MAX - 1);
-        directory_name_result[NAME_MAX - 1] = 0;
+                 FILE_NAME_MAXIMUM_LENGTH - 1);
+        directory_name_result[FILE_NAME_MAXIMUM_LENGTH - 1] = 0;
 }
 
 
