@@ -52,7 +52,7 @@ medusa_uri_list_is_in_directory (gpointer database,
         database_record = (MedusaRDBRecord) record;
         directory_in_query = directory_argument.string;
 
-        directory_in_record = g_new0 (char, NAME_MAX);
+        directory_in_record = g_new0 (char, FILE_NAME_MAXIMUM_LENGTH);
         medusa_rdb_record_get_field_value (database_record,
                                            medusa_uri_list_get_field_info (uri_list),
                                            MEDUSA_URI_LIST_DIRECTORY_NAME_FIELD_TITLE,
@@ -80,7 +80,7 @@ medusa_uri_list_is_in_directory_tree (gpointer database,
         database_record = (MedusaRDBRecord) record;
         directory_in_query = directory_argument.string;
 
-        directory_in_record = g_new0 (char, NAME_MAX);
+        directory_in_record = g_new0 (char, FILE_NAME_MAXIMUM_LENGTH);
         medusa_rdb_record_get_field_value (database_record,
                                            medusa_uri_list_get_field_info (uri_list),
                                            MEDUSA_URI_LIST_DIRECTORY_NAME_FIELD_TITLE,
@@ -108,7 +108,7 @@ medusa_uri_list_is_named (gpointer database,
         database_record = (MedusaRDBRecord) record;
         file_in_query = file_argument.string;
 
-        file_in_record = g_new0 (char, NAME_MAX);
+        file_in_record = g_new0 (char, FILE_NAME_MAXIMUM_LENGTH);
         medusa_rdb_record_get_field_value (database_record,
                                               medusa_uri_list_get_field_info (uri_list),
                                               MEDUSA_URI_LIST_FILE_NAME_FIELD_TITLE,
@@ -138,7 +138,7 @@ medusa_uri_list_has_name_regexp_matching (gpointer database,
         database_record = (MedusaRDBRecord) record;
         file_regular_expression = file_argument.string;
 
-        file_in_record = g_new0 (char, NAME_MAX);
+        file_in_record = g_new0 (char, FILE_NAME_MAXIMUM_LENGTH);
         medusa_rdb_record_get_field_value (database_record,
                                               medusa_uri_list_get_field_info (uri_list),
                                               MEDUSA_URI_LIST_FILE_NAME_FIELD_TITLE,
@@ -193,7 +193,7 @@ medusa_uri_list_is_in_directory_regexp_matching (gpointer database,
         database_record = (MedusaRDBRecord) record;
         directory_regular_expression = directory_argument.string;
 
-        directory_in_record = g_new0 (char, NAME_MAX);
+        directory_in_record = g_new0 (char, FILE_NAME_MAXIMUM_LENGTH);
         medusa_rdb_record_get_field_value (database_record,
                                            medusa_uri_list_get_field_info (uri_list),
                                            MEDUSA_URI_LIST_DIRECTORY_NAME_FIELD_TITLE,
@@ -246,7 +246,7 @@ medusa_uri_list_has_name_containing (gpointer database,
         database_record = (MedusaRDBRecord) record;
         file_fragment_in_query = file_argument.string;
 
-        file_in_record = g_new0 (char, NAME_MAX);
+        file_in_record = g_new0 (char, FILE_NAME_MAXIMUM_LENGTH);
         medusa_rdb_record_get_field_value (database_record,
                                            medusa_uri_list_get_field_info (uri_list),
                                            MEDUSA_URI_LIST_FILE_NAME_FIELD_TITLE,
@@ -283,7 +283,7 @@ medusa_uri_list_is_in_directory_containing (gpointer database,
         database_record = (MedusaRDBRecord) record;
         directory_fragment_in_query = directory_argument.string;
 
-        directory_in_record = g_new0 (char, NAME_MAX);
+        directory_in_record = g_new0 (char, FILE_NAME_MAXIMUM_LENGTH);
         medusa_rdb_record_get_field_value (database_record,
                                               medusa_uri_list_get_field_info (uri_list),
                                               MEDUSA_URI_LIST_DIRECTORY_NAME_FIELD_TITLE,
@@ -310,7 +310,7 @@ medusa_uri_list_has_file_name_starting_with (gpointer database,
         database_record = (MedusaRDBRecord) record;
         file_prefix_in_query = file_argument.string;
 
-        file_in_record = g_new0 (char, NAME_MAX);
+        file_in_record = g_new0 (char, FILE_NAME_MAXIMUM_LENGTH);
         medusa_rdb_record_get_field_value (database_record,
                                               medusa_uri_list_get_field_info (uri_list),
                                               MEDUSA_URI_LIST_FILE_NAME_FIELD_TITLE,
@@ -339,7 +339,7 @@ medusa_uri_list_has_file_name_ending_with (gpointer database,
         database_record = (MedusaRDBRecord) record;
         file_suffix_in_query = file_argument.string;
 
-        file_in_record = g_new0 (char, NAME_MAX);
+        file_in_record = g_new0 (char, FILE_NAME_MAXIMUM_LENGTH);
         medusa_rdb_record_get_field_value (database_record,
                                            medusa_uri_list_get_field_info (uri_list),
                                            MEDUSA_URI_LIST_FILE_NAME_FIELD_TITLE,
