@@ -36,6 +36,10 @@
 #define MEDUSA_REINDEX_REQUEST_ACCEPTED "Reindexing now\n"
 #define MEDUSA_REINDEX_REQUEST_DENIED_BUSY "Cannot reindex right now\n"
 
+#define MEDUSA_INDEX_SERVICE_AVAILABILITY_REQUEST "Is index service available?\n"
+#define MEDUSA_INDEX_SERVICE_AVAILABILITY_UP "Index service is available.\n"
+#define MEDUSA_INDEX_SERVICE_AVAILABILITY_BUSY "An index is currently being created\n"
+
 #define MEDUSA_LAST_INDEX_UPDATE_TIME_REQUEST "Get last indexing time\n"
 
 
