@@ -251,7 +251,8 @@ medusa_search_service_connection_read_search_result (MedusaSearchServiceConnecti
 
 
 
-void medusa_search_service_connection_destroy (MedusaSearchServiceConnection *connection)
+void 
+medusa_search_service_connection_destroy (MedusaSearchServiceConnection *connection)
 {
         g_free (connection->uri);
         medusa_indexed_search_destroy (connection->indexed_search);
