@@ -27,7 +27,7 @@
 #define MEDUSA_SERVICE_PRIVATE_H
 
 
-int          medusa_initialize_socket_for_requests      (char *socket_path);
+int          medusa_initialize_socket_for_requests      (const char *socket_path);
 
  
 #endif /* MEDUSA_SERVICE_PRIVATE_H */
