@@ -61,9 +61,11 @@
 #define CDROM_DRIVE_STATUS	0x5326  /* Get tray position, etc. */
 #define CDSL_CURRENT    	((int) (~0U>>1))
 #define STOPLIST_FILE_NAME      MEDUSA_SYSCONFDIR "/file-index-stoplist"
+#define STOPLIST_MOUNT_TYPE     MEDUSA_SYSCONFDIR "/mount-type-stoplist"
 
 static void                 file_stoplist_initialize                          (void);
 static void                 unsearched_mount_list_initialize                  (void);
+static void                 medusa_unsearched_locations_shutdown              (void);
 
 #ifdef HAVE_GETMNTINFO
 static gboolean             mount_point_is_cdrom                              (const struct statfs *fs_list);
@@ -79,23 +81,24 @@ static void                 unsearched_location_free                          (g
 
 static GHashTable *unsearched_locations = NULL;
 
-const char *mount_type_skip_list[] = {
-        "nfs",
-        "afs",
-        "shm",
-        "autofs",
-        NULL
-};
+static GList *mount_type_skip_list = NULL;
+
+
 
 static gboolean
 mount_type_is_in_skip_list (const char *mount_type)
 {
-        int i;
-        
+        GList *current_item;
+        char *current_string;
+       
         g_return_val_if_fail (mount_type != NULL, TRUE);
 
-        for (i = 0; mount_type_skip_list[i] != NULL; i++) {
-                if (strcmp (mount_type_skip_list[i], mount_type) == 0) {
+        for ( current_item = mount_type_skip_list ;
+              current_item != NULL ;
+              current_item = g_list_next (current_item)) {
+
+		current_string = (char *)current_item->data; 
+                if (strcmp (current_string, mount_type) == 0) {
                         return TRUE;
                 }
         }
@@ -119,16 +122,26 @@ medusa_is_unsearched_location (const char *file_name)
 void
 medusa_unsearched_locations_initialize (void)
 {
-        unsearched_locations = g_hash_table_new (g_str_hash,
-                                                 g_str_equal);
-                                                 
-        file_stoplist_initialize ();
-        unsearched_mount_list_initialize ();
+        static gboolean unsearched_locations_initialized = FALSE;
+
+        if (!unsearched_locations_initialized) {
+                unsearched_locations = g_hash_table_new (g_str_hash,
+                                                         g_str_equal);
+                
+                file_stoplist_initialize ();
+                unsearched_mount_list_initialize ();
+                
+                g_atexit (medusa_unsearched_locations_shutdown);
+                
+                unsearched_locations_initialized = TRUE;
+        }
 }
 
-void
+static void
 medusa_unsearched_locations_shutdown (void)
 {
+	GList *list_item;
+
         if (unsearched_locations) {
                 g_hash_table_foreach (unsearched_locations,
                                       unsearched_location_free,
@@ -137,6 +150,64 @@ medusa_unsearched_locations_shutdown (void)
                 g_hash_table_destroy (unsearched_locations);
                 unsearched_locations = NULL;
         }
+
+        for ( list_item = mount_type_skip_list ;
+              list_item != NULL ;
+              list_item = g_list_next (list_item)) {
+
+		g_free (list_item->data);
+		list_item->data = NULL;
+	}
+	g_list_free (mount_type_skip_list);
+        mount_type_skip_list = NULL;
+}
+
+#define GETLINE_INITIAL_BUFFER_SIZE 256
+
+/**
+ * getline_dup
+ *
+ * reads newline (or CR) or EOF terminated line from stream, allocating the return
+ * buffer as appropriate
+ **/
+/* FIXME bugzilla.eazel.com 5055: Belongs in a library, not here. */
+/* (it is also present in nautilus/src/nautilus-first-time-druid.c) */
+static char * 
+getline_dup (FILE* stream)
+{
+	char *ret;
+	size_t ret_size;
+	size_t ret_used;
+	int char_read;
+	gboolean done;
+
+	ret = g_malloc (GETLINE_INITIAL_BUFFER_SIZE);
+	ret_size = GETLINE_INITIAL_BUFFER_SIZE;
+
+	for ( ret_used = 0, done = FALSE ;
+	      !done && (EOF != (char_read = fgetc (stream))) ; 
+	      ret_used++) {
+		
+		if (ret_size == (ret_used + 1)) {
+			ret_size *= 2;
+			ret = g_realloc (ret, ret_size); 
+		}
+		if ('\n' == char_read || '\r' == char_read ) {
+			done = TRUE;
+			ret [ret_used] = '\0';
+		} else {
+			ret [ret_used] = char_read;
+		}
+	}
+
+	if (ret_used == 0) {
+		g_free (ret);
+		ret = NULL;
+	} else {
+		ret [ret_used] = '\0';
+	}
+
+	return ret;
 }
 
 
@@ -144,7 +215,7 @@ static void
 file_stoplist_initialize  (void)
 {
 	FILE *stop_list_handle;
-	char next_file[1024];
+	char *next_file;
 
         g_return_if_fail (unsearched_locations != NULL);
 
@@ -154,27 +225,54 @@ file_stoplist_initialize  (void)
                 return;
         }
 
-        /* FIXME: We should not use fscanf. */
-        /* FIXME: This allows a buffer overrun, because we read into a
-         * fixed-size buffer. It might be easy to fix with a field width.
-         */
-	while (fscanf (stop_list_handle, "%s\n", next_file) != EOF) {
+	while (NULL != (next_file = getline_dup (stop_list_handle))) {
                 /* Skip comment lines */
                 if (next_file[0] == '#') {
+                	g_free (next_file);
+                	next_file = NULL;
                         continue;
                 }
                 g_hash_table_insert (unsearched_locations,
-                                     g_strdup (next_file),
+                                     next_file,
                                      GINT_TO_POINTER (1));
+                next_file = NULL;
 	}
 	fclose (stop_list_handle);
         
 }
 
-/* Don't index or search nfs mount points and removeable media, for now */
-static void              
-unsearched_mount_list_initialize (void)
+static void
+load_mount_type_skip_list()
 {
+	FILE *file_handle;
+	char *line;
+
+	g_return_if_fail (mount_type_skip_list == NULL);
+
+	file_handle = fopen (STOPLIST_MOUNT_TYPE, "r");
+
+	if (file_handle == NULL) {
+		return;
+	}
+
+	while (NULL != (line = getline_dup (file_handle))) {
+                /* Skip comment lines */
+                if (line[0] == '#') {
+                	g_free (line);
+                	line = NULL;
+                        continue;
+                }
+
+                mount_type_skip_list = g_list_prepend (mount_type_skip_list, line);
+                line = NULL;
+	}
+	fclose (file_handle);
+}
+
+static void
+unsearched_mount_list_initialize_internal (void)
+{
+
 #ifdef HAVE_GETMNTINFO
 
 	struct statfs *fs_list;
@@ -240,6 +338,16 @@ unsearched_mount_list_initialize (void)
         g_free (mount_entry);
 
 #endif
+
+}
+
+
+/* Don't index or search nfs mount points and removeable media, for now */
+static void              
+unsearched_mount_list_initialize (void)
+{
+	load_mount_type_skip_list ();
+	unsearched_mount_list_initialize_internal ();
 }
 
 static gboolean
