@@ -45,8 +45,8 @@ static gboolean             str_ends_with_slash              (const char *direct
 
 
 char *
-medusa_full_path_from_directory_and_file (const char *directory_name,
-                                          const char *file_name)
+medusa_full_path_from_directory_and_file_name (const char *directory_name,
+                                               const char *file_name)
 {
         g_return_val_if_fail (directory_name != NULL, NULL);
         g_return_val_if_fail (file_name != NULL, NULL);
@@ -60,8 +60,8 @@ medusa_full_path_from_directory_and_file (const char *directory_name,
 }
 
 char *
-medusa_full_uri_from_directory_and_file (const char *directory_uri,
-                                         const char *file_name)
+medusa_full_uri_from_directory_uri_and_file_name (const char *directory_uri,
+                                                  const char *file_name)
 {
         char *file_name_uri_encoded, *uri;
 
@@ -155,6 +155,28 @@ medusa_g_list_partition (GList	          *list,
 	return predicate_true;
 }
 
+GList *
+medusa_g_list_remove_deep_custom (GList *list,
+                                  MedusaGPredicateFunc removable,
+                                  GDestroyNotify destroy_data,
+                                  gpointer user_data)
+{
+        GList *new_list, *node;
+
+        new_list = NULL;
+        for (node = list; node != NULL; node = node->next) {
+                if (!removable (node->data, user_data)) {
+                        new_list = g_list_append (new_list, node->data);
+                }
+                else {
+                        destroy_data (node->data);
+                }
+        }
+
+        g_list_free (list);
+
+        return new_list;
+}
 
 gboolean
 medusa_g_list_forall (GList *list,
@@ -583,7 +605,7 @@ medusa_keyword_hash_table_create_for_directory (GHashTable **keywords_hash_table
         g_free (private_metafile_path);
         if (result == GNOME_VFS_ERROR_NOT_FOUND) {
                 /* Look for a public metafile. */
-                public_metafile_path = medusa_full_path_from_directory_and_file
+                public_metafile_path = medusa_full_path_from_directory_and_file_name
                         (directory_path, MEDUSA_PUBLIC_METAFILE_NAME);
                 result = keyword_hash_table_populate_from_metafile
                         (hash_table, public_metafile_path);
