@@ -480,14 +480,14 @@ BadWindow_ehandler (Display *display, XErrorEvent *error)
            handler is used so that we can cope with the fact that the window
            may have been destroyed <30 seconds after it was created.
    */
-        if (error->error_code == BadWindow ||
-            error->error_code == BadMatch ||
-            error->error_code == BadDrawable)
-                return 0;
-        else {
+        if (error->error_code != BadWindow &&
+            error->error_code != BadMatch &&
+            error->error_code != BadDrawable) {
                 /* Probably a bad, bad error */
                 exit (1);
         }
+
+        return 0;
 }
 
 struct notice_events_timer_arg {
