@@ -43,7 +43,7 @@
 
 #define   CACHED_PERMISSION_NOT_CACHED 0
 #define   CACHED_PERMISSION_CAN_READ 1
-#define CACHED_PERMISSION_CANNOT_READ 2
+#define   CACHED_PERMISSION_CANNOT_READ 2
 
 typedef struct {
         int uid;
@@ -56,12 +56,14 @@ GList *user_keys;
 static int             get_user_key                              (int uid, int pid);
 
 
-static gboolean        calculate_permissions_for_file            (char *file_name, 
+static gboolean        calculate_permissions_for_file            (const char *file_name, 
                                                                   int uid);
 
-static gboolean        can_read_this_directory                   (char *directory, 
-                                                                  int uid, 
+static gboolean        can_read_this_file                        (const char *directory, 
+
+                                                                 int uid, 
                                                                   GHashTable *cache);
+
 void
 medusa_authenticate_create_cookie_file (char *request_line)
 {
@@ -128,15 +130,16 @@ medusa_authenticate_is_correct_cookie (int uid, int pid, int cookie)
 
 
 gboolean
-medusa_authenticate_uid_can_read (char *uri, int uid, GHashTable *cache)
+medusa_authenticate_user_can_see_file (char *uri, int uid, GHashTable *cache)
 {
-        /* Even though the permissions are stored in the file database, it is
-           necessary to recheck these so that they are absolutely up to date */
-        struct stat file_stats;
         char *path_name;
         char *location, *next_directory;
-        int stat_result;
+        gboolean file_still_exists;
 
+
+        g_return_val_if_fail (uri != NULL, FALSE);
+
+        /* The superuser can read any file on the system */
         if (uid == 0) {
                 return TRUE;
         }
@@ -144,47 +147,44 @@ medusa_authenticate_uid_can_read (char *uri, int uid, GHashTable *cache)
         path_name = gnome_vfs_get_local_path_from_uri (uri);
         g_return_val_if_fail (path_name != NULL, FALSE);
 
+        if (can_read_this_file ("/", uid, cache) == FALSE) {
+                return FALSE;
+        }
+        
         location = path_name + 1;
-        /* check that each directory is readable by the user */
+        /* Check that each parent directory is readable by the user, starting from the top */
         while (location != NULL) {
                 if (strchr (location, '/')) {
                         next_directory = g_strndup (path_name, strchr (location, '/') - path_name);
                         location = strchr (location, '/') + 1;
                 }
                 else {
-                        next_directory = g_strdup (path_name);
-                        location = NULL;
+                        break;
                 }
-                if (can_read_this_directory (next_directory, uid, cache) == FALSE) {
+
+#ifdef AUTHENTICATION_DEBUG                
+                g_print ("Checking permissions on %s\n", next_directory);
+#endif
+                if (can_read_this_file (next_directory, uid, cache) == FALSE) {
                         g_free (next_directory);
                         g_free (path_name);
                         return FALSE;
                 }
                 g_free (next_directory);
         }
-        stat_result = lstat (path_name, &file_stats);
-#ifdef SEARCH_RESULTS_DEBUG
-        if (stat_result == -1) {
-                printf ("Error reading file %s for authentication\n", path_name);
-        }
-#endif
-        
+
+        file_still_exists = (access (path_name, F_OK) == 0);
         g_free (path_name);
-
-        if (stat_result == -1) {
-                return FALSE;
-        }
-
-        return TRUE;
+        return file_still_exists;
 }
 
 
 static gboolean
-can_read_this_directory (char *directory, int uid, GHashTable *cache)
+can_read_this_file (const char *directory, int uid, GHashTable *cache)
 {
         int cached_value;
         gboolean user_has_read_permissions_here;
-#ifdef SEARCH_RESULTS_DEBUG  
+#ifdef AUTHENTICATION_DEBUG  
         printf ("trying to locate cached permissions for %s\n", directory);
 #endif 
         cached_value = GPOINTER_TO_INT (g_hash_table_lookup (cache, directory));
@@ -192,12 +192,12 @@ can_read_this_directory (char *directory, int uid, GHashTable *cache)
                 
         case CACHED_PERMISSION_NOT_CACHED:
                 /* directory hasn't been cached yet */
-#ifdef SEARCH_RESULTS_DEBUG
+#ifdef AUTHENTICATION_DEBUG
                 printf ("Permissions not cached yet , calculating them myself \n");
 #endif
                 user_has_read_permissions_here = calculate_permissions_for_file (directory, uid);
                 if (user_has_read_permissions_here) {
-#ifdef SEARCH_RESULTS_DEBUG
+#ifdef AUTHENTICATION_DEBUG
                         printf ("user can read %s\n", directory);
 #endif
                         g_hash_table_insert (cache,
@@ -206,7 +206,7 @@ can_read_this_directory (char *directory, int uid, GHashTable *cache)
                         return TRUE;
                 }
                 else {
-#ifdef SEARCH_RESULTS_DEBUG
+#ifdef AUTHENTICATION_DEBUG
                         printf ("user can't read %s\n", directory);
 #endif
                         g_hash_table_insert (cache,
@@ -216,12 +216,12 @@ can_read_this_directory (char *directory, int uid, GHashTable *cache)
                 }
                 break;
         case CACHED_PERMISSION_CAN_READ:
-#ifdef SEARCH_RESULTS_DEBUG
+#ifdef AUTHENTICATION_DEBUG
                 printf ("Permissions cached as positive\n");
 #endif
                 return TRUE;
         case CACHED_PERMISSION_CANNOT_READ:
-#ifdef SEARCH_RESULTS_DEBUG
+#ifdef AUTHENTICATION_DEBUG
                 printf ("permissions cached as negative\n");
 #endif
                 return FALSE;
@@ -232,7 +232,7 @@ can_read_this_directory (char *directory, int uid, GHashTable *cache)
 }
 
 static gboolean
-calculate_permissions_for_file (char *file_name, int uid)
+calculate_permissions_for_file (const char *file_name, int uid)
 {
         int stat_result;
         struct stat file_stats;
@@ -243,7 +243,7 @@ calculate_permissions_for_file (char *file_name, int uid)
         if (stat_result == -1) {
                 return FALSE;
         }
-#ifdef SEARCH_RESULTS_DEBUG
+#ifdef AUTHENTICATION_DEBUG
         printf ("Calculating permissions for %s\n", file_name);
 #endif
         if (uid == 0) {
