@@ -31,7 +31,7 @@ gboolean     medusa_authenticate_is_cookie_request         (char *request_line);
 gboolean     medusa_authenticate_is_correct_cookie         (int uid, 
 							    int gid, 
 							    int cookie);
-gboolean     medusa_authenticate_uid_can_read              (char *uri,
+gboolean     medusa_authenticate_user_can_see_file         (char *uri,
 							    int uid,
 							    GHashTable *cache);
 
