@@ -38,8 +38,6 @@
 #include <string.h>
 
 
-
-
 static void                 handle_authenticated_request     (MedusaMasterDB *master_db,
                                                               const char *search_uri,
                                                               int uid, 
@@ -215,13 +213,26 @@ present_query_results (GList *results,
         GHashTable *read_cache;
         char send_buffer[MAX_LINE + 1];
 
+#ifdef PRESENT_QUERY_RESULTS_DEBUG
+        g_print ("Presenting query results\n");
+#endif
         read_cache = g_hash_table_new (g_str_hash, g_str_equal);
         for (iterator = results ; iterator != NULL; iterator = iterator->next) {
-                if (medusa_authenticate_uid_can_read ((char *) iterator->data, uid, read_cache)) {
+                if (medusa_authenticate_user_can_see_file ((char *) iterator->data, uid, read_cache)) {
                         memset (send_buffer, 0, MAX_LINE);
                         strncpy (send_buffer, iterator->data, MAX_LINE - 1);
                         transmit_string (send_buffer, client_fd);
+#ifdef PRESENT_QUERY_RESULTS_DEBUG
+                        g_print ("Returning %s\n", (char *) iterator->data);
+#endif
+                        
                 }
+#ifdef PRESENT_QUERY_RESULTS_DEBUG
+                else {
+                        g_print ("Not returning %s because user cannot see it\n", 
+                                 (char *) iterator->data);
+                }
+#endif
         }
         g_hash_table_foreach (read_cache, free_entries, NULL);
         g_hash_table_destroy (read_cache);
