@@ -35,7 +35,7 @@
 #include <medusa-text-index-queries.h>
 #include <stdlib.h>
 
-
+#define INDEX_NAME "text-index-test"
 
 
 int main ()
@@ -46,26 +46,23 @@ int main ()
         int i;
         MedusaMasterDB *master_db;
         MedusaReadLock *read_lock;
+        MedusaWriteLock *write_lock;
 
         /* acquire lock */
-	read_lock = medusa_read_lock_get (MEDUSA_FILE_INDEX_READ_LOCK_FILE);
-        if (read_lock == NULL) {
+	write_lock = medusa_write_lock_get (INDEX_NAME);
+        if (write_lock == NULL) {
                 puts ("ERROR: can't acquire database lock");
                 exit (-1);
         }
-        master_db = medusa_master_db_new (ROOT_DIRECTORY,
-                                          MEDUSA_DB_LOG_EVERYTHING,
-                                          URI_LIST_NAME,
-                                          FILE_SYSTEM_DB_FILE_NAME,
-                                          FILE_NAME_HASH_NAME,
-                                          DIRECTORY_NAME_HASH_NAME,
-                                          MIME_TYPE_HASH_NAME,
-                                          KEYWORD_SETS_FILE_NAME,
-                                          TEXT_INDEX_START_FILE_NAME,
-                                          TEXT_INDEX_LOCATION_FILE_NAME,
-                                          TEXT_INDEX_WORD_FILE_NAME,
-                                          TEXT_INDEX_TEMP_FILE_NAME);
-        
+        medusa_master_db_create_index (ROOT_DIRECTORY,
+                                       INDEX_NAME,
+                                       TRUE,  /* Don't bother with the idle service for tests */
+                                       MEDUSA_DB_LOG_EVERYTHING);
+        medusa_write_lock_release (write_lock);
+        read_lock = medusa_read_lock_get (INDEX_NAME);
+        master_db = medusa_master_db_open (ROOT_DIRECTORY,
+                                           INDEX_NAME,
+                                           MEDUSA_DB_LOG_EVERYTHING);
         printf ("Enter words to look for in the text index\n");
         scanf ("%s", next_line);
         printf ("Looking for all the words X%sX\n", next_line);
